/*
Title: Milestone 4 - Data Preparation
Name: ENTER YOUR NAME HERE
Date: ENTER THE DATE HERE
*/

/// 1. Open the women's recode file (update this command for your computer)
use "C:\Users\Owner\Documents\a_work\d_dhs\rwanda_2010\RWIR61FL.DTA", clear

/// 2. Keep only those women interview in the domestic violence module
keep if v044==1

/// 3. Use the "lookfor" command to identify woman (& relationship, household, 
///    and community) variables to keep
lookfor "ever been"	// d105a - d105k
lookfor age			// v013
lookfor education	// v106
lookfor occupation	// v717
lookfor justified	// v744a - v744e
lookfor radio		// v158
lookfor forced		// d126 
lookfor decides		// v743b
lookfor wives		// v505
lookfor refuse		// v850a
lookfor condom		// v850b
lookfor wealth		// v190
lookfor members		// v136
lookfor residence	// v025 

/// 4. Add variables identified in step 2 to the keep statement
*Note that we keep v001-v003 v005 v021 and v023 because they describe the study 
*design, and d005 because this is the special domestic violence sample weight
keep v001-v003 v021 v023 d005 d105a - d105k v013 v106 v717 v744a-v744e v158 ///
d126 v743b v505 v850a v850b v190 v136 v025 v501

/// 5. Generate wife_id
generate long wife_id = ((1000+v001)*10000) + (v002*100) + v003

/// 6. Save reduced set of woman variables (update command for your computer) 
save "C:\Users\Owner\Dropbox\Work_main\p_rwanda_ipv\data\ir_temp.dta", replace


////////////////////////////////////////////////////////////////////


/// 7. Open the men's recode file (update this command for your computer)
use "C:\Users\Owner\Documents\a_work\d_dhs\rwanda_2010\RWMR61FL.DTA", clear

/// 8. Use the "lookfor" command to identify man variables to keep
lookfor age			// mv013
lookfor education	// mv106
lookfor occupation	// mv717
lookfor justified	// mv744a - mv744e
lookfor radio		// mv158
lookfor partners	// mv766a 

/// 9. Add variables identified in step 8 to the keep statement
*Note we keep mv001 mv002 mv034_1-mv034_8 to generate a wife_id to link husband 
*data to wife data
keep mcaseid mv001 mv002 mv034_1-mv034_8 mv013 mv106 mv717 mv744a-mv744e ///
 mv158 mv766a

/// 10. Reshape the husband data from wide (by husband) to long (by wife); 
///     drop "empty" records or wives that do not live in household
reshape long mv034_, i(mcaseid) j(wifeline)
drop if mv034_==. | mv034_==0

/// 11. Generage wife_id
generate long wife_id = ((1000+mv001)*10000) + (mv002*100) + mv034_

/// 12. Data cleaning - we find 5 women who were listed as wife more than once, 
///     so we drop these duplicated records.
duplicates list wife_id
duplicates drop wife_id, force

/// 13. Save reduced set of man variables (update command for your computer)
save "C:\Users\Owner\Dropbox\Work_main\p_rwanda_ipv\data\mr_temp.dta", replace


////////////////////////////////////////////////////////////////////


/// 14. Merge wife and husband data by wife_id; keep records of all women 
///     terviewed about domestic violence since this corresponds to the sample 
///     weights (update this command for your computer)
use "C:\Users\Owner\Dropbox\Work_main\p_rwanda_ipv\data\ir_temp.dta", clear
merge 1:1 wife_id using ///
"C:\Users\Owner\Dropbox\Work_main\p_rwanda_ipv\data\mr_temp.dta"
* (_merge==1) 2558 women, husband not interviewed
* (_merge==2) 682 umarried men
* (_merge==3) 2450 women whose husband was interviewed
keep if _merge==1 | _merge==3


////////////////////////////////////////////////////////////////////

/// 15. Generate all variables needed for analysis
*HINT: For all yes/no variables, we will code "don't know" responses as "no"

* sample weight
generate weight = d005/1000000
label var weight "Domestic violence module sample weight"

* subpopulation
recode _merge (1 = 0 "No") (3 = 1 "Yes"), gen(couple)
label var couple "Subpopulation of couple data" 

* Wife experienced physical or sexual violence sometimes or often in the last 12 months  (w_ipv)
tab1 d105a - d105k
labelbook d105a d105b
generate w_ipv = .
replace w_ipv = 0 if d105a==0 | d105a==3 | d105a==4
replace w_ipv = 0 if d105b==0 | d105b==3 | d105b==4
replace w_ipv = 0 if d105c==0 | d105c==3 | d105c==4
replace w_ipv = 0 if d105d==0 | d105d==3 | d105d==4
replace w_ipv = 0 if d105e==0 | d105e==3 | d105e==4
replace w_ipv = 0 if d105f==0 | d105f==3 | d105f==4
replace w_ipv = 0 if d105h==0 | d105h==3 | d105h==4
replace w_ipv = 0 if d105j==0 | d105j==3 | d105j==4
replace w_ipv = 0 if d105k==0 | d105k==3 | d105k==4
replace w_ipv = 1 if d105a==1 | d105a==2
replace w_ipv = 1 if d105b==1 | d105b==2
replace w_ipv = 1 if d105c==1 | d105c==2
replace w_ipv = 1 if d105d==1 | d105d==2
replace w_ipv = 1 if d105e==1 | d105e==2
replace w_ipv = 1 if d105f==1 | d105f==2
replace w_ipv = 1 if d105h==1 | d105h==2
replace w_ipv = 1 if d105j==1 | d105j==2
replace w_ipv = 1 if d105k==1 | d105k==2
label var w_ipv "Wife experienced physical or sexual violence sometimes or often in the last 12 months "
label define w_ipv_lab 0 "No" 1 "Yes"
label value w_ipv w_ipv_lab
tab v501 w_ipv, m


*Wifes age (w_age)
tab v013
label list v013
gen w_age = .
replace w_age = 1 if v013==1 | v013==2
replace w_age = 2 if v013==3 | v013==4
replace w_age = 3 if v013==5 | v013==6 | v013==7
label var w_age "Wifes age"
label define w_age_lab 1 "15-24" 2 "25-34" 3 "35-49"
label value w_age w_age_lab
tab v013 w_age, missing

*Wifes education (w_edu)
tab v106
label list v106
gen w_edu = .
replace w_edu = 0 if v106==0 | v106==1
replace w_edu = 1 if v106==2 | v106==3
label var w_edu "Wifes education"
label define w_edu_lab 0 "Less than secondary" 1 "Secondary+"
label value w_edu w_edu_lab
tab v106 w_edu, missing

*Wifes employment (w_emp)
tab v717
label list v717
gen w_emp = .
replace w_emp = 0 if v717==0 | v717==4
replace w_emp = 1 if v717==1 | v717==2 | v717==3 | v717==5 | v717==6 | ///
					 v717==7 | v717==8 | v717==9
label var w_emp "Wifes employment"
label define w_emp_lab 0 "Unemployed, self-employed agriculture" 1 "Employed"
label value w_emp w_emp_lab
tab v717 w_emp, m

*Wife believes IPV is justified (w_belief)
tab1 v744a v744b v744c v744d v744e
label list v744a v744b v744c v744d v744e
gen w_belief = .
replace w_belief = 0 if v744a==0 | v744b==0 | v744c==0 | v744d==0 | v744e==0
replace w_belief = 0 if v744a==8 | v744b==8 | v744c==8 | v744d==8 | v744e==8
replace w_belief = 1 if v744a==1 | v744b==1 | v744c==1 | v744d==1 | v744e==1
label var w_belief "Wife believes IPV is justified"
label define w_belief_lab 0 "No" 1 "Yes"
label value w_belief w_belief_lab
tab v744a w_belief, m
tab v744b w_belief, m
tab v744c w_belief, m
tab v744d w_belief, m
tab v744e w_belief, m

* Wife listens to radio at least once a week (w_radio)
tab v158
label list v158
gen w_radio = .
replace w_radio = 0 if v158==0 | v158==1
replace w_radio = 1 if v158==2 | v158==3
label var w_radio "Wife listens to radio at least once a week"
label define w_radio_lab 0 "No" 1 "Yes"
label value w_radio w_radio_lab
tab v158 w_radio, m

* Forced to have sex as child (before age 15) (w_forced)
* HINT: we know the age for women who reported any forced sex; 
* for no forced sex age is missing
tab d126
label list d126
gen w_forced = 0
replace w_forced = 1 if d126>=5 & d126<15
replace w_forced = . if d126==98 | d126==99
label var w_forced "Forced to have sex as child (before age 15)"
label define w_forced_lab 0 "No" 1 "Yes"
label value w_forced w_forced_lab
tab d126 w_forced, m

* Husbands age (h_age)
* HINT: data will be missing for women without an interviewed husband
tab mv013
label list mv013
gen h_age = .
replace h_age = 1 if mv013==1 | mv013==2
replace h_age = 2 if mv013==3 | mv013==4
replace h_age = 3 if mv013==5 | mv013==6
replace h_age = 4 if mv013==7 | mv013==8 | mv013==9
label var h_age "Husband's age"
label define h_age_lab 1 "15-24" 2 "25-34" 3 "35-44" 4 "45-59"
label value h_age h_age_lab
tab mv013 h_age, m

* Husbands education (h_edu)
tab mv106
label list mv106
gen h_edu = .
replace h_edu = 0 if mv106==0 | mv106==1
replace h_edu = 1 if mv106==2 | mv106==3
label var h_edu "Husband's education"
label define h_edu_lab 0 "Less than secondary" 1 "Secondary+"
label value h_edu h_edu_lab
tab mv106 h_edu, m

* Husbands employment (h_emp)
tab mv717
label list mv717
gen h_emp = .
replace h_emp = 0 if mv717==0 | mv717==4
replace h_emp = 1 if mv717==1 | mv717==2 | mv717==3 | mv717==5 | mv717==6 | ///
					 mv717==7 | mv717==8 | mv717==9
label var h_emp "Husbands employment"
label define h_emp_lab 0 "Unemployed, self-employed agriculture" 1 "Employed"
label value h_emp h_emp_lab
tab mv717 h_emp, m

* Husband believes IPV is justified (h_belief)
tab1 mv744a mv744b mv744c mv744d mv744e
label list mv744a mv744b mv744c mv744d mv744e
gen h_belief = .
replace h_belief=0 if mv744a==0 | mv744b==0 | mv744c==0 | mv744d==0 | mv744e==0 
replace h_belief=0 if mv744a==8 | mv744b==8 | mv744c==8 | mv744d==8 | mv744e==8 
replace h_belief=1 if mv744a==1 | mv744b==1 | mv744c==1 | mv744d==1 | mv744e==1
label var h_belief "Husband believes IPV is justified"
label define h_belief_lab 0 "No" 1 "Yes"
label value h_belief h_belief_lab
tab mv744a h_belief, m
tab mv744b h_belief, m
tab mv744c h_belief, m
tab mv744d h_belief, m
tab mv744e h_belief, m

* Husband listened to radio in last week (h_radio)
tab mv158
label list mv158
gen h_radio = .
replace h_radio = 0 if mv158==0 | mv158==1
replace h_radio = 1 if mv158==2 | mv158==3
label var h_radio "Husband listens to radio at least once a week"
label define h_radio_lab 0 "No" 1 "Yes"
label value h_radio h_radio_lab
tab mv158 h_radio, m

* Husband had non-wife sex partner in last 12 months (h_nonwife)
tab mv766a
gen h_nonwife = .
replace h_nonwife = 0 if mv766a==0
replace h_nonwife = 1 if mv766a>=1 & mv766a<=3
label var h_nonwife "Husband had non-wife sex partner in last 12 months"
label define h_nonwife_lab 0 "No" 1 "Yes"
label value h_nonwife h_nonwife_lab
tab mv766a h_nonwife, m

* Person who decides large household purchases (hh_purch)
* HINT: "respondent" in this case is the wife
tab v743b
label list v743b
gen hh_purch = .
replace hh_purch = 1 if v743b==2
replace hh_purch = 2 if v743b==4
replace hh_purch = 3 if v743b==1 | v743b==3 | v743b==5 | v743b==6
label var hh_purch "Person who decides large household purchases"
label define hh_purch_lab 1 "Husband & wife" 2 "Husband alone" ///
						  3 "Wife alone, other" 
label value hh_purch hh_purch_lab
tab v743b hh_purch, m

* Polygamous marriage (hh_poly)
tab v505
label list v505
gen hh_poly = .
replace hh_poly = 0 if v505==0 | v505==98
replace hh_poly = 1 if v505>=1 & v505<=6
label var hh_poly "Polygamous marriage"
label define hh_poly_lab 0 "No" 1 "Yes"
label value hh_poly hh_poly_lab
tab v505 hh_poly, m

* Wife says it is okay to refuse sex or request a condom (hh_refuse)
tab1 v850a v850b
label list v850a v850b
gen hh_refuse = .
replace hh_refuse = 0 if v850a==0 | v850b==8 | v850a==8 | v850b==8
replace hh_refuse = 1 if v850a==1 | v850b==1
label var hh_refuse "Wife says it is okay to refuse sex or request a condom"
label define hh_refuse_lab 0 "No" 1 "Yes"
label value hh_refuse hh_refuse_lab
tab v850a hh_refuse, m
tab v850b hh_refuse, m

* Household wealth (hh_wealth)
tab v190
label list v190
gen hh_wealth=.
replace hh_wealth = 0 if v190==1
replace hh_wealth = 1 if v190>=2 & v190<=5
label var hh_wealth "Household wealth"
label define hh_wealth_lab 0 "Poorest quintile" 1 "Top 4 quintiles"
label value hh_wealth hh_wealth_lab
tab v190 hh_wealth, m

* Number of household members (hh_size)
tab v136
gen hh_size = .
replace hh_size = 1 if v136>=1 & v136<=4
replace hh_size = 2 if v136>=5 & v136<=8
replace hh_size = 3 if v136>=9 & v136<=16
label var hh_size "Number of household members"
label define hh_size_lab 1 "1-4" 2 "5-8" 3 "9+"
labe value hh_size hh_size_lab
tab v136 hh_size, m

* Residence (comm_res)
tab v025
label list v025
gen comm_res = .
replace comm_res = 1 if v025==1
replace comm_res = 2 if v025==2
label var comm_res "Residence"
label define comm_res_lab 1 "Urban" 2 "Rural"
label value comm_res comm_res_lab
tab v025 comm_res, m

label var wife_id "Wife's unique ID"
rename v021 psu
rename v023 district

keep wife_id psu district weight couple w_ipv w_age w_edu w_emp w_belief ///
w_radio w_forced h_age h_edu h_emp h_belief h_radio h_nonwife hh_purch ///
hh_poly hh_refuse hh_wealth hh_size comm_res

order wife_id weight psu district couple w_ipv w_age w_edu w_emp w_belief ///
w_radio w_forced h_age h_edu h_emp h_belief h_radio h_nonwife hh_purch ///
hh_poly hh_refuse hh_wealth hh_size comm_res

////////////////////////////////////////////////////////////////////


/// 16. Save final dataset (update this command for your computer)
save "C:\Users\Owner\Dropbox\Work_main\p_rwanda_ipv\data\ipv.dta", replace


/*This is to produce counts to match in M4
		foreach var of varlist w_ipv w_age w_edu w_emp w_belief ///
			w_radio w_forced h_age h_edu h_emp h_belief h_radio h_nonwife ///
			hh_purch hh_poly hh_refuse hh_wealth hh_size comm_res {
			tabout `var' using "C:\Users\Owner\Dropbox\Work_main\p_rwanda_ipv\output\freq_v1.txt", ///
			c(freq) f(0) clab("") mi append
			}




